/*===================

run with options

--last --bestp --cuts

yields cycling

===================*/

set	T;
param	cap{T};

set	N;
set	B within N;
param	sul0{N};
param	sul1{N};
param	ash1{N};
param	vol0{N};
param	vol1{N};
param	grd0{N};
param	src1{N};
param	dem{N};

set	L;
param	sul{L};
param	ash{L};
param	vol{L};
param	grd{L};
param	sup0{L};
param	sup1{L};
set	Src{T} within L;

set	M;
param	flt{M} in T;

param	cshp{L,M};
param	clnd{M,N};

set	R{j in M} := {i in Src[flt[j]], k in N :
		grd0[k] <= grd[i] and (k in B or ash[i] <= ash1[k] and
		sul0[k] <= sul[i] and sul[i] <= sul1[k] and
		vol0[k] <= vol[i] and vol[i] <= vol1[k])};

set	R2 := setof{j in M, (i,k) in R[j]} (i,k);
set	R3 := setof{j in M, (i,k) in R[j]} (i,j,k);

var	x{R3} integer >= 0;
var	y{R2} binary;

minimize f	: sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} (cshp[i,j] + clnd[j,k]) * x[i,j,k];

r1{i in L}	: sup0[i]  <=  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k]  <=  sup1[i];
r2{k in N}	: dem[k]   <=  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k];

r3{k in B}	: sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k] * sul[i]  >=  sul0[k] *
		  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k];
r4{k in B}	: sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k] * sul[i]  <=  sul1[k] *
		  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k];

r5{k in B}	: sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k] * ash[i]  <=  ash1[k] *
		  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k];

r6{k in B}	: sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k] * vol[i]  >=  vol0[k] *
		  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k];
r7{k in B}	: sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k] * vol[i]  <=  vol1[k] *
		  sum{j in M} cap[flt[j]] * sum{(i,k) in R[j]} x[i,j,k];

r8{(i,k) in R2}	: sum{j in M : (i,k) in R[j]} cap[flt[j]] * x[i,j,k]  <=  y[i,k] * sup1[i];

r9{k in N}	: sum{(i,k) in R2} y[i,k]  <=  src1[k];

solve;

display f;
display{(i,j,k) in R3 : x[i,j,k] > 0} x[i,j,k];

data;

param :	T :	cap :=
	1	20
	2	65
	3	110;

param :	N :	sul0	sul1	ash1	vol0	vol1	grd0	src1	dem :=
	1	0.45	0.65	7.5	37.5	45	40	2	473
	2	0.8	1.2	16	30	34	48	2	800
	3	0.8	1.2	16	28	35	48	2	710
	4	0.45	0.65	14	27	35	45	2	1291
	5	0.45	0.65	14	27	35	45	2	1291
	6	0.45	0.65	14	27	35	45	2	1291
	7	0.45	0.65	14	27	35	45	3	1291
	8	0.50	0.65	16	28	45	45	2	1498
	9	0.65	1.5	13.5	29	35	50	3	1283
	10	0.65	1.5	13.5	29	35	50	4	1283
	11	0.45	0.65	13.5	27	35	50	4	1407
	12	0.45	0.65	13.5	27	35	50	3	1407;

set	B 4 5 6 7 9 10 11 12;

param :	L :	sul	ash	vol	grd	sup0	sup1 :=
	1	1.11	12.37	33.41	58	800	1000
	2	0.97	15.2	33.45	54	1790	2210
	3	0.5	8.91	42.22	49	300	500
	4	0.63	15.0	26.76	50	720	880
	5	0.5	14.48	32.1	55	690	910
	6	0.53	13.49	25.79	52	912	1764
	7	0.70	12.04	29.49	49	760	1703
	8	0.58	4.51	40.85	46	900	1100
	9	0.63	8.91	41.6	48	0	2000
	10	0.45	15.0	26.91	50	0	2000
	11	0.57	14.5	30.74	50	0	2000
	12	0.58	4.51	40.85	46	0	2000
	13	0.53	13.49	25.79	52	0	2000;

set	Src[1] 8 12;
set	Src[2] 1 2 3 4 5 6 7 9 10 11 13;
set	Src[3] 1 2 4 5 6 7 10 11 13;

param :	M :	flt :=
	1	2
	2	2
	3	1
	4	3;

param	cshp :
		1	2	3	4 :=
	1	78.8	68.8	82.4	82.4
	2	78.8	68.8	82.4	82.4
	3	67.0	52.0	73.0	73.0
	4	62.0	51.0	67.0	67.0
	5	62.0	51.0	67.0	67.0
	6	54.5	43.5	60.0	60.0
	7	54.5	43.5	60.0	60.0
	8	57.7	49.2	63.0	63.0
	9	59.0	48.0	65.0	65.0
	10	59.0	48.0	65.0	65.0
	11	59.0	48.0	65.0	65.0
	12	59.0	48.0	65.0	65.0
	13	59.0	48.0	65.0	65.0;

param	clnd :
		1	2	3	4	5	6	7	8	9	10	11	12 :=
	1	15.3	13.2	13.2	4.0	4.0	4.0	4.0	22.2	25.3	25.3	25.3	25.3
	2	37.5	35.4	35.4	22.2	22.2	22.2	22.2	0	3.1	3.1	3.1	3.1
	3	5.1	20.3	20.3	30.2	30.2	30.2	30.2	52	55	55	55	55
	4	0	26.2	26.2	39.4	39.4	39.4	39.4	48.1	62.3	62.3	62.3	62.3;

end;
